@@ -8,6 +8,7 @@ from twisted.internet import defer
 from twisted.trial.runner import filenameToModule
 from twisted.python import usage, reflect
 
+from ooni import otime
 from ooni.tasks import Measurement
 from ooni.utils import log, checkForRoot, sanitize_options
 from ooni.settings import config
@@ -201,7 +202,7 @@ class NetTestLoader(object):
             input_file_hashes.append(input_file['hash'])
 
         options = sanitize_options(self.options)
-        test_details = {'start_time': time.time(),
+        test_details = {'start_time': otime.epochToUTC(time.time()),
                         'probe_asn': config.probe_ip.geodata['asn'],
                         'probe_cc': config.probe_ip.geodata['countrycode'],
                         'probe_ip': config.probe_ip.geodata['ip'],
@@ -527,6 +528,14 @@ class NetTest(object):
                 if self.report:
                     post = defer.DeferredList(measurements)
 
+                    @post.addBoth
+                    def set_runtime(results):
+                        runtime = time.time() - test_instance._start_time
+                        for _, m in results:
+                            m.testInstance.report['test_runtime'] = runtime
+                        test_instance.report['test_runtime'] = runtime
+                        return results
+
                     # Call the postProcessor, which must return a single report
                     # or a deferred
                     post.addCallback(test_instance.postProcessor)
