@@ -1,5 +1,7 @@
 # -*- encoding: utf-8 -*-
+import os
 import random
+import tempfile
 from distutils.spawn import find_executable
 
 from twisted.python import usage
@@ -28,7 +30,7 @@ class BridgeReachability(nettest.NetTestCase):
     description = "A test for checking if bridges are reachable " \
                   "from a given location."
     author = "Arturo Filastò"
-    version = "0.1.1"
+    version = "0.1.2"
 
     usageOptions = UsageOptions
 
@@ -49,11 +51,10 @@ class BridgeReachability(nettest.NetTestCase):
         self.tor_progress = 0
         self.timeout = int(self.localOptions['timeout'])
 
-        if self.timeout > config.advanced.measurement_timeout:
-            log.err("The measurement timeout is less than the bridge reachability test timeout")
-            log.err("Adjust your ooniprobe.conf file by setting the "
-                    "advanced: measurement_timeout: value to %d" % self.timeout)
-            raise errors.InvalidConfigFile("advanced->measurement_timeout < %d" % self.timeout)
+        fd, self.tor_logfile = tempfile.mkstemp()
+        os.close(fd)
+        fd, self.obfsproxy_logfile = tempfile.mkstemp()
+        os.close(fd)
 
         self.report['error'] = None
         self.report['success'] = None
@@ -65,6 +66,7 @@ class BridgeReachability(nettest.NetTestCase):
         self.report['tor_progress_summary'] = None
         self.report['tor_log'] = None
         self.report['obfsproxy_version'] = str(onion.obfsproxy_details['version'])
+        self.report['obfsproxy_log'] = None
         self.report['bridge_address'] = None
 
         self.bridge = self.input
@@ -130,11 +132,14 @@ class BridgeReachability(nettest.NetTestCase):
             (self.bridge, onion.tor_details['version']))
 
         transport_name = onion.transport_name(self.bridge)
+
+        if transport_name:
+            self.report['transport_name'] = transport_name
+
         if transport_name and transport_name == 'fte' and self.fteproxy_bin:
             config.ClientTransportPlugin = "%s exec %s --managed" % (
                 transport_name, self.fteproxy_bin)
             log.debug("Using fte from %s" % self.fteproxy_bin)
-            self.report['transport_name'] = transport_name
             self.report['bridge_address'] = self.bridge.split(' ')[1]
         elif transport_name and transport_name == 'fte'\
                 and not self.fteproxy_bin:
@@ -142,8 +147,10 @@ class BridgeReachability(nettest.NetTestCase):
             self.report['error'] = 'missing-fteproxy'
             return
         elif transport_name and self.pyobfsproxy_bin:
-            config.ClientTransportPlugin = "%s exec %s managed" % (
-                transport_name, self.pyobfsproxy_bin)
+            config.ClientTransportPlugin = ("%s exec %s --log-min-severity info "
+                "--log-file %s managed") % (transport_name,
+                                            self.pyobfsproxy_bin,
+                                            self.obfsproxy_logfile)
             if onion.OBFSProxyVersion('0.2') > onion.obfsproxy_details['version']:
                 log.err(
                     "The obfsproxy version you are using appears to be outdated."
@@ -151,7 +158,6 @@ class BridgeReachability(nettest.NetTestCase):
                 self.report['error'] = 'old-obfsproxy'
                 return
             log.debug("Using pyobfsproxy from %s" % self.pyobfsproxy_bin)
-            self.report['transport_name'] = transport_name
             self.report['bridge_address'] = self.bridge.split(' ')[1]
         elif transport_name and not self.pyobfsproxy_bin:
             log.err(
@@ -174,7 +180,7 @@ class BridgeReachability(nettest.NetTestCase):
 
         config.Bridge = self.bridge
         config.UseBridges = 1
-        config.log = 'notice'
+        config.log = ['notice stdout', 'notice file %s' % self.tor_logfile]
         config.save()
 
         def updates(prog, tag, summary):
@@ -198,7 +204,17 @@ class BridgeReachability(nettest.NetTestCase):
         @d.addErrback
         def setup_failed(failure):
             log.msg("Failed to connect to %s" % self.bridge)
-            self.report['tor_log'] = failure.value.message
             self.report['success'] = False
+            self.report['error'] = 'timeout-reached'
+            return
+
+        @d.addCallback
+        def write_log(_):
+            with open(self.tor_logfile) as f:
+                self.report['tor_log'] = f.read()
+            os.remove(self.tor_logfile)
+            with open(self.obfsproxy_logfile) as f:
+                self.report['obfsproxy_log'] = f.read()
+            os.remove(self.obfsproxy_logfile)
 
         return d
