@@ -18,6 +18,7 @@ from ooni.settings import config
 
 class TestTaskManager(unittest.TestCase):
     timeout = 1
+
     def setUp(self):
         self.measurementManager = MockTaskManager()
         self.measurementManager.concurrency = 20
@@ -28,9 +29,19 @@ class TestTaskManager(unittest.TestCase):
         self.clock = task.Clock()
         data_dir = os.path.dirname(os.path.abspath(__file__))
         data_dir = os.path.join(data_dir, '..', '..', 'data')
+        self.old_datadir = ""
+        if hasattr(config.global_options, 'datadir'):
+            self.old_datadir = config.global_options['datadir']
         config.global_options['datadir'] = data_dir
         config.set_paths()
 
+    def tearDown(self):
+        if self.old_datadir == "":
+            del config.global_options['datadir']
+        else:
+            config.global_options['datadir'] = self.old_datadir
+        config.set_paths()
+
     def schedule_successful_tasks(self, task_type, number=1):
         all_done = []
         for x in range(number):
@@ -39,6 +50,7 @@ class TestTaskManager(unittest.TestCase):
             self.measurementManager.schedule(mock_task)
 
         d = defer.DeferredList(all_done)
+
         @d.addCallback
         def done(res):
             for task_result, task_instance in self.measurementManager.successes:
@@ -56,16 +68,17 @@ class TestTaskManager(unittest.TestCase):
             self.measurementManager.schedule(mock_task)
 
         d = defer.DeferredList(all_done)
+
         @d.addCallback
         def done(res):
             # 10*2 because 2 is the number of retries
-            self.assertEqual(self.measurementManager.failures, number*3)
+            self.assertEqual(self.measurementManager.failures, number * 3)
             # XXX @aagbsn is there a reason why you switched to using an int
             # over a using a list?
             # self.assertEqual(len(self.measurementManager.failures), number*3)
             # for task_result, task_instance in self.measurementManager.failures:
-            #     self.assertEqual(task_result, mockFailure)
-            #     self.assertIsInstance(task_instance, task_type)
+            # self.assertEqual(task_result, mockFailure)
+            # self.assertIsInstance(task_instance, task_type)
 
         return d
 
@@ -100,7 +113,7 @@ class TestTaskManager(unittest.TestCase):
             self.assertEqual(self.measurementManager.failures, 1)
             # self.assertEqual(len(self.measurementManager.failures), 1)
             # for task_result, task_instance in self.measurementManager.failures:
-            #     self.assertIsInstance(task_instance, task_type)
+            # self.assertIsInstance(task_instance, task_type)
 
         return mock_task.done
 
@@ -119,9 +132,9 @@ class TestTaskManager(unittest.TestCase):
         @mock_task.done.addBoth
         def done(res):
             self.assertEqual(self.measurementManager.failures, 1)
-            #self.assertEqual(len(self.measurementManager.failures), 1)
+            # self.assertEqual(len(self.measurementManager.failures), 1)
             # for task_result, task_instance in self.measurementManager.failures:
-            #     self.assertIsInstance(task_instance, task_type)
+            # self.assertIsInstance(task_instance, task_type)
 
             for task_result, task_instance in self.measurementManager.successes:
                 self.assertEqual(task_result, 42)
@@ -129,7 +142,6 @@ class TestTaskManager(unittest.TestCase):
 
         return mock_task.done
 
-
     def test_schedule_failing_one_task(self):
         return self.schedule_failing_tasks(MockFailTask)
 
@@ -155,11 +167,11 @@ class TestTaskManager(unittest.TestCase):
         @mock_task.done.addCallback
         def done(res):
             self.assertEqual(self.measurementManager.failures, 1)
-            #self.assertEqual(len(self.measurementManager.failures), 1)
+            # self.assertEqual(len(self.measurementManager.failures), 1)
             # self.assertEqual(self.measurementManager.failures,
-            #         [(mockFailure, mock_task)])
+            # [(mockFailure, mock_task)])
             self.assertEqual(self.measurementManager.successes,
-                    [(42, mock_task)])
+                             [(42, mock_task)])
 
         return mock_task.done
 
@@ -179,13 +191,14 @@ class TestTaskManager(unittest.TestCase):
         @d.addCallback
         def done(res):
             self.assertEqual(self.measurementManager.failures, number)
-            #self.assertEqual(len(self.measurementManager.failures), number)
+            # self.assertEqual(len(self.measurementManager.failures), number)
             for task_result, task_instance in self.measurementManager.successes:
                 self.assertEqual(task_result, 42)
                 self.assertIsInstance(task_instance, MockFailOnceTask)
 
         return d
 
+
 class TestMeasurementManager(unittest.TestCase):
     def setUp(self):
         mock_director = MockDirector()
@@ -208,9 +221,10 @@ class TestMeasurementManager(unittest.TestCase):
         @mock_task.done.addCallback
         def done(res):
             self.assertEqual(self.mockNetTest.successes,
-                    [42])
+                             [42])
 
             self.assertEqual(len(self.mockNetTest.successes), 1)
+
         return mock_task.done
 
     def test_schedule_failing_one_measurement(self):
@@ -220,7 +234,7 @@ class TestMeasurementManager(unittest.TestCase):
         @mock_task.done.addErrback
         def done(failure):
             self.assertEqual(self.measurementManager.failures, 3)
-            #self.assertEqual(len(self.measurementManager.failures), 3)
+            # self.assertEqual(len(self.measurementManager.failures), 3)
 
             self.assertEqual(failure, mockFailure)
             self.assertEqual(len(self.mockNetTest.successes), 0)
