@@ -49,11 +49,8 @@ class TestYAMLReporter(unittest.TestCase):
             os.remove(self.filename)
 
     def test_write_report(self):
-        test = MockTest()
-
         y_reporter = YAMLReporter(test_details)
         y_reporter.createReport()
-        y_reporter.testDone(test, 'spam')
         with open(y_reporter.report_path) as f:
             self.filename = y_reporter.report_path
             report_entries = yaml.safe_load_all(f)
@@ -61,13 +58,6 @@ class TestYAMLReporter(unittest.TestCase):
             entry = report_entries.next()
             assert all(x in entry for x in ['test_name', 'test_version'])
 
-            entry = report_entries.next()
-            # Check for first entry of report
-            assert all(x in entry
-                       for x in ['report_content', 'input',
-                                 'test_name', 'test_started',
-                                 'test_runtime'])
-
 
 class TestOONIBReporter(unittest.TestCase):
 
