@@ -1,8 +1,12 @@
+import shutil
 import string
 import random
 import glob
 import os
 
+import gzip
+from zipfile import ZipFile
+
 from ooni import otime
 from ooni import errors
 
@@ -131,6 +135,7 @@ def generate_filename(testDetails, prefix=None, extension=None, filename=None):
 
     return final_filename
 
+
 def sanitize_options(options):
     """
     Strips all possible user identifying information from the ooniprobe test
@@ -142,3 +147,27 @@ def sanitize_options(options):
         option = os.path.basename(option)
         sanitized_options.append(option)
     return sanitized_options
+
+
+def unzip(filename, dst):
+    assert filename.endswith('.zip')
+    dst_path = os.path.join(
+        dst,
+        os.path.basename(filename).replace(".zip", "")
+    )
+    with open(filename) as zfp:
+        zip_file = ZipFile(zfp)
+        zip_file.extractall(dst_path)
+    return dst_path
+
+
+def gunzip(filename, dst):
+    assert filename.endswith(".gz")
+    dst_path = os.path.join(
+        dst,
+        os.path.basename(filename).replace(".gz", "")
+    )
+    with open(dst_path, "w+") as fw:
+        gzip_file = gzip.open(filename)
+        shutil.copyfileobj(gzip_file, fw)
+        gzip_file.close()
