@@ -4,40 +4,37 @@
 # Here we make sure that the HTTP Headers sent and received are True. By this
 # we mean that they are not normalized and that the ordering is maintained.
 
-import struct
 import itertools
 from copy import copy
 
-from zope.interface import implements
 from twisted.web import client, _newclient, http_headers
-from twisted.web._newclient import Request, RequestNotSent, RequestGenerationFailed, TransportProxyProducer, STATUS
-from twisted.internet import protocol, reactor
-from twisted.internet.protocol import ClientFactory, Protocol
-from twisted.internet.endpoints import TCP4ClientEndpoint, SSL4ClientEndpoint
-from twisted.internet import interfaces, defer
-from twisted.internet.defer import Deferred, succeed, fail, maybeDeferred
+from twisted.web._newclient import RequestNotSent, RequestGenerationFailed, TransportProxyProducer, STATUS
+from twisted.internet import reactor
+from twisted.internet.defer import Deferred, fail, maybeDeferred, failure
 
 from txsocksx.http import SOCKS5Agent
 from txsocksx.client import SOCKS5ClientFactory
+
 SOCKS5ClientFactory.noisy = False
 
 from ooni.utils import log
 
+
 class TrueHeaders(http_headers.Headers):
     def __init__(self, rawHeaders=None):
         self._rawHeaders = dict()
         if rawHeaders is not None:
             for name, values in rawHeaders.iteritems():
                 if type(values) is list:
-                  self.setRawHeaders(name, values[:])
+                    self.setRawHeaders(name, values[:])
                 elif type(values) is dict:
-                  self._rawHeaders[name.lower()] = values
+                    self._rawHeaders[name.lower()] = values
                 elif type(values) is str:
-                  self.setRawHeaders(name, values)
+                    self.setRawHeaders(name, values)
 
     def setRawHeaders(self, name, values):
         if name.lower() not in self._rawHeaders:
-          self._rawHeaders[name.lower()] = dict()
+            self._rawHeaders[name.lower()] = dict()
         self._rawHeaders[name.lower()]['name'] = name
         self._rawHeaders[name.lower()]['values'] = values
 
@@ -71,7 +68,7 @@ class TrueHeaders(http_headers.Headers):
                 pass
 
         for k, v in itertools.chain(headers_a.getAllRawHeaders(), \
-                headers_b.getAllRawHeaders()):
+                                    headers_b.getAllRawHeaders()):
             field_names.append(k)
 
         for name in field_names:
@@ -90,6 +87,7 @@ class TrueHeaders(http_headers.Headers):
             return self._rawHeaders[name.lower()]['values']
         return default
 
+
 class HTTPClientParser(_newclient.HTTPClientParser):
     def logPrefix(self):
         return 'HTTPClientParser'
@@ -107,6 +105,7 @@ class HTTPClientParser(_newclient.HTTPClientParser):
             headers = self.headers
         headers.addRawHeader(name, value)
 
+
 class HTTP11ClientProtocol(_newclient.HTTP11ClientProtocol):
     def request(self, request):
         if self._state != 'QUIESCENT':
@@ -133,7 +132,7 @@ class HTTP11ClientProtocol(_newclient.HTTP11ClientProtocol):
                 self._state = 'GENERATION_FAILED'
                 self.transport.loseConnection()
                 self._finishedRequest.errback(
-                    Failure(RequestGenerationFailed([err])))
+                    failure.Failure(RequestGenerationFailed([err])))
             else:
                 log.err(err, 'Error writing request, but not in valid state '
                              'to finalize request: %s' % self._state)
@@ -142,19 +141,24 @@ class HTTP11ClientProtocol(_newclient.HTTP11ClientProtocol):
 
         return self._finishedRequest
 
+
 class _HTTP11ClientFactory(client._HTTP11ClientFactory):
     noisy = False
+
     def buildProtocol(self, addr):
         return HTTP11ClientProtocol(self._quiescentCallback)
 
+
 class HTTPConnectionPool(client.HTTPConnectionPool):
     _factory = _HTTP11ClientFactory
 
+
 class TrueHeadersAgent(client.Agent):
     def __init__(self, *args, **kw):
         super(TrueHeadersAgent, self).__init__(*args, **kw)
         self._pool = HTTPConnectionPool(reactor, False)
 
+
 class TrueHeadersSOCKS5Agent(SOCKS5Agent):
     def __init__(self, *args, **kw):
         super(TrueHeadersSOCKS5Agent, self).__init__(*args, **kw)
